# Fancy Galaxy Code (FGC)

Fancy Galaxy Code (FGC) is an open source standard for fast and reliable data representation while maintaining a nice look and feel.
This package enables easy integration into your projects.

## Usage
Example usage:  
```
from fgc_tools import FGCCreator

FGCCreator.create_fgc(data, output_file, color_start, color_end, background_color)
```